
<a href="https://github.com/Aarhus-Psychiatry-Research/timeseriesflattener"><img src="https://github.com/centre-for-humanities-computing/conspiracies/blob/main/docs/_static/icon.png?raw=true" width="100" align="right"/></a>

# Conspiracies
[![python versions](https://img.shields.io/badge/Python-%3E=3.8-blue)](https://github.com/centre-for-humanities-computing/conspiracies)
[![Code style: black](https://img.shields.io/badge/Code%20Style-Black-black)](https://black.readthedocs.io/en/stable/the_black_code_style/current_style.html)
[![github actions pytest](https://github.com/centre-for-humanities-computing/conspiracies/actions/workflows/tests.yml/badge.svg)](https://github.com/centre-for-humanities-computing/conspiracies/actions)
[![github actions docs](https://github.com/centre-for-humanities-computing/conspiracies/actions/workflows/documentation.yml/badge.svg)](https://centre-for-humanities-computing.github.io/conspiracies/)

Discovering and examining conspiracies using NLP.


## 🔧 Installation
Installation using pip:
```bash
pip install pip --upgrade
pip install conspiracies
```

Note that this package is dependent on AllenNLP and thus does not support Windows.
For developers please check out the development installation instructions in
the [documentation](https://centre-for-humanities-computing.github.io/conspiracies/installation.html).


# 📖 Documentation

| Documentation         |                                                  |
| --------------------- | ------------------------------------------------ |
| 🔧 **[Installation]**  | Installation instructions for using this package |
| 🎛 **[Documentation]** | A minimal and developing documentation           |
| 👩‍💻 **[Tutorials]**     | Tutorials for using this package                 |
| 📚 **[FAQ]**           | Frequently asked questions                       |

[Documentation]: https://centre-for-humanities-computing.github.io/conspiracies/index.html
[Installation]: https://centre-for-humanities-computing.github.io/conspiracies/installation.html
[Tutorials]: https://centre-for-humanities-computing.github.io/conspiracies/tutorials.html
[FAQ]: https://centre-for-humanities-computing.github.io/conspiracies/faq.html

# 💬 Where to ask questions

| Type                           |                        |
| ------------------------------ | ---------------------- |
| 📚 **FAQ**                      | [FAQ]                  |
| 🚨 **Bug Reports**              | [GitHub Issue Tracker] |
| 🎁 **Feature Requests & Ideas** | [GitHub Issue Tracker] |
| 👩‍💻 **Usage Questions**          | [GitHub Discussions]   |
| 🗯 **General Discussion**       | [GitHub Discussions]   |

[FAQ]: https://centre-for-humanities-computing.github.io/conspiracies/faq.html
[github issue tracker]: https://github.com/centre-for-humanities-computing/conspiracies/issues
[github discussions]: https://github.com/centre-for-humanities-computing/conspiracies/discussions

